==> foundation-0.0.45.tgz: package/Default/Tools/Build/BuilderTool.js <==
import { WorldRegister } from "../../../Data/World/WorldRegister.js";
import { ChunkDataTool } from "../Data/WorldData/ChunkDataTool.js";
import { ThreadComm } from "@divinestar/threads/";
import { LocationBoundTool } from "../../Tools/Classes/LocationBoundTool.js";
import { TaskTool } from "../../Tools/Tasks/TasksTool.js";
const parentComm = ThreadComm.parent;
export class BuilderTool extends LocationBoundTool {
    static _chunkTool = new ChunkDataTool();
    tasks = new TaskTool();
    data = {
        LOD: 1,
    };
    setLOD(lod) {
        this.data.LOD = lod;
        return this;
    }
    clearAll() {
        parentComm.runTasks("clear-all", []);
    }
    addChukBuildToQuee() {
        this.tasks.build.chunk.queued.add(this.location);
    }
    runChunkBuildQueue() {
        this.tasks.build.chunk.queued.run(() => { });
    }
    buildChunk() {
        this.tasks.build.chunk.deferred.run([this.location, 1], () => { });
        return this;
    }
    buildColumn(onDone) {
        this.tasks.build.column.deferred.run(this.location, onDone ? onDone : (data) => { });
        return this;
    }
    removeColumn() {
        const column = WorldRegister.column.get(this.location);
        if (!column)
            return false;
        if (column.chunks.length == 0)
            return false;
        parentComm.runTasks("remove-column", this.location);
        return this;
    }
    fillColumn() {
        WorldRegister.column.fill(this.location);
        return this;
    }
    removeColumnsOutsideRadius(radius) {
        parentComm.runTasks("remove-column-outside-radius", [this.location, radius]);
    }
}

==> foundation-0.0.52.tgz: package/Default/Tools/Build/BuilderTool.js <==
import { WorldRegister } from "../../../Data/World/WorldRegister.js";
import { ChunkDataTool } from "../Data/WorldData/ChunkDataTool.js";
import { ThreadComm } from "@divinestar/threads/";
import { LocationBoundTool } from "../../Tools/Classes/LocationBoundTool.js";
import { TaskTool } from "../../Tools/Tasks/TasksTool.js";
const parentComm = ThreadComm.parent;
export class BuilderTool extends LocationBoundTool {
    static _chunkTool = new ChunkDataTool();
    tasks = new TaskTool();
    data = {
        LOD: 1,
    };
    setLOD(lod) {
        this.data.LOD = lod;
        return this;
    }
    clearAll() {
        parentComm.runTasks("clear-all", []);
    }
    addChukBuildToQuee() {
        this.tasks.build.chunk.queued.add(this.location);
    }
    runChunkBuildQueue() {
        this.tasks.build.chunk.queued.run(() => { });
    }
    buildChunk() {
        this.tasks.build.chunk.deferred.run([this.location, 1], () => { });
        return this;
    }
    buildColumn(onDone) {
        this.tasks.build.column.deferred.run(this.location, onDone ? onDone : (data) => { });
        return this;
    }
    removeColumn() {
        const column = WorldRegister.instance.column.get(this.location);
        if (!column)
            return false;
        if (column.chunks.length == 0)
            return false;
        parentComm.runTasks("remove-column", this.location);
        return this;
    }
    fillColumn() {
        WorldRegister.instance.column.fill(this.location);
        return this;
    }
    removeColumnsOutsideRadius(radius) {
        parentComm.runTasks("remove-column-outside-radius", [this.location, radius]);
    }
}
